unit OlLog;
{***************************************************************
(C) SoftOL
***************************************************************}

interface

uses Classes, SysUtils;

type

    TOLogFileEvent = procedure (Var NewStr :String) of object;

    TOLogFile = class(TComponent)
    private     // Private declarations
        FDelete         :Boolean;
        FName           :string;
        FLogText        :string;
        FEnabled        :Boolean;
        FOLogFileEvent  :TOLogFileEvent;
    protected   // Protected declarations
        procedure SetFileName(Name: string);
        procedure SetLogText(Str: string);
    public      // Public declarations
        constructor Create(AOwner: TComponent); override;
        Procedure Add(const Str :String);
        Procedure AddTime(const Str :String);
        Procedure AddShift(Shift :Word; const Str :String);
        Procedure AddShiftFile(Shift :Word; const FileName :String);
        Procedure AddBlank;
        Procedure Clear;
    published   // Published declarations
        property DeleteOnChangeName: Boolean read FDelete write FDelete;
        property FileName: string read FName write SetFileName;
        property LogText: string read FLogText write SetLogText;
        property Enabled: Boolean read FEnabled write FEnabled;
        property OnBeforeWrite: TOLogFileEvent read FOLogFileEvent write FOLogFileEvent;
    end;

procedure Register;

implementation

Procedure TOLogFile.Add(const Str :String);
begin
    SetLogText(Str);
end;

Procedure TOLogFile.AddTime(const Str :String);
begin
    SetLogText(DateTimeToStr(Now)+' '+Str);
end;

Procedure TOLogFile.AddShift(Shift :Word; const Str :String);
var ss  :string;
    i   :Word;
begin
    ss:= '';
    for i := 2 to Shift*4 do ss:=ss+' ';
    SetLogText(ss+' '+Str);
end;

Procedure TOLogFile.AddShiftFile(Shift :Word; const FileName :String);
var ss  :string;
    Str :String;
    i   :Word;
    F   :Text;
begin
    ss:= '';
    for i := 2 to Shift*4 do ss:=ss+' ';
    if (Filename <> '') and (Enabled) then begin
        try
            AssignFile(F, Filename);
            Reset(F);
            while not eof(F) do begin
                Readln(F, Str);
                SetLogText(ss+' '+Str);
            end;
            CloseFile(F);
        except
             on E: Exception do  SetLogText(ss+' ??? '+E.Message+' <'+FileName+'>');
        end;
    end;
end;

Procedure TOLogFile.AddBlank;
begin
    SetLogText('');
end;

procedure TOLogFile.SetLogText(Str: string);
var F: Text;
begin
    (*$i-*)
    if (Filename <> '') and (Enabled) then begin
        AssignFile(F, Filename);
        if (FileExists(Filename) = True) then Append(F)
        else ReWrite(F);
        FLogText := Str;
        if Assigned(FOLogFileEvent) then FOLogFileEvent(FLogText);
        WriteLn(F, FLogText);
        Close(F);
    end;
    (*$i+*)
end;

procedure TOLogFile.SetFileName(Name: string);
begin
    FName := NAme;
    (*$i-*)
    if (FDelete = True) then begin
        DeleteFile(Filename);
    end;
    (*$i+*)
end;

Procedure TOLogFile.Clear;
begin
    (*$i-*)
    if FileExists(Filename) then DeleteFile(Filename);
    (*$i+*)
end;

constructor TOLogFile.Create(AOwner: TComponent);
begin
    inherited;
    Filename := '';
    FLogText := '';
    DeleteOnChangeName := True;
    Enabled := True;
end;

procedure Register;
begin
    RegisterComponents('Ol', [TOLogFile]);
end;

end.

